@@ -1,6 +1,6 @@
 package Simo::Util;
 
-our $VERSION = '0.0201';
+our $VERSION = '0.0202';
 
 use warnings;
 use strict;
@@ -16,16 +16,22 @@ sub o{
     return Simo::Wrapper->create( obj => $_[0] );
 }
 
+my $old_err = '';
+my $err_obj_cash;
 sub err{
-    if( @_ ){
-        return Simo::Error->create_err_str( @_ );
-    }
-    else{
-        my $err_str = $@;
-        my $err_obj = Simo::Error->create_from_err_str( $err_str );
-        $@ = $err_str;
-        return $err_obj;
-    }
+    return unless $@;
+    return $err_obj_cash if $old_err eq "$@";
+    
+    $old_err = "$@";
+    my $err = $@;
+    
+    my $is_simo_err = eval{ $err->isa( 'Simo::Error' ) };
+    
+    my $simo_error = $is_simo_err ? $err : Simo::Error->new( msg => "$err", pos => '' );
+    
+    $err_obj_cash = $simo_error;
+    $@ = $err;
+    return $simo_error;
 }
 
 =head1 NAME
@@ -34,7 +40,7 @@ Simo::Util - Utility Class for Simo
 
 =head1 VERSION
 
-Version 0.0201
+Version 0.0202
 
 =cut
 
